@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 from dataclasses import dataclass, field
+from typing import Dict
 
 
 @dataclass
@@ -14,7 +15,8 @@ class BMSMapMetaMetadata:
 
 @dataclass
 class BMSMapMetaMisc:
-    lnEndChannel: bytes = b'ZZ'
+    ln_end_channel: bytes = b'ZZ'
+    exbpms: Dict[bytes, float] = field(default_factory=lambda: {})
 
 
 @dataclass
