@@ -57,6 +57,7 @@ class OsuHold(Hold, OsuNoteMeta):
     def write_string(self, keys: int) -> str:
         """ Exports a .osu writable string """
         return f"{OsuNoteMeta.column_to_x_axis(self.column, keys=keys)},{192}," \
-               f"{int(self.offset)},{128},{self.hitsound_set},{int(self.offset + self.length)}:" \
-               f"{self.sample_set}:{self.addition_set}:{self.custom_set}:{self.volume}:{self.hitsound_file}"
+               f"{int(self.offset)},{128},{int(self.hitsound_set)},{int(self.offset + self.length)}:" \
+               f"{int(self.sample_set)}:{int(self.addition_set)}:{int(self.custom_set)}:" \
+               f"{int(self.volume)}:{self.hitsound_file}"
 
