@@ -1,5 +1,4 @@
 from reamber.osu.lists.OsuBpmList import OsuBpmList
-from reamber.osu.lists.OsuNotePkg import OsuNotePkg
 from reamber.osu.lists.OsuSvList import OsuSvList
 
-__all__ = ['OsuSvList', 'OsuNotePkg', 'OsuBpmList']
+__all__ = ['OsuSvList', 'OsuBpmList']
